@@ -50,7 +50,7 @@ ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpr
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeExpressionStatement * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "expression";
@@ -70,7 +70,7 @@ ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpr
 static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeExpressionStatement * self;
 	self = VALA_CCODE_EXPRESSION_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (VALA_IS_CCODE_COMMA_EXPRESSION (self->priv->_expression)) {
 		ValaCCodeCommaExpression* _tmp1;
 		ValaCCodeExpression* _tmp0;
@@ -116,7 +116,7 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 
 static void vala_ccode_expression_statement_write_expression (ValaCCodeExpressionStatement* self, ValaCCodeWriter* writer, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_EXPRESSION_STATEMENT (self));
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	if (expr != NULL) {
