@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEFRAGMENT_H__
-#define __VALACCODEFRAGMENT_H__
+#ifndef __CCODE_VALACCODEFRAGMENT_H__
+#define __CCODE_VALACCODEFRAGMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -47,17 +47,19 @@ typedef struct _ValaCCodeFragmentPrivate ValaCCodeFragmentPrivate;
  * Represents a container for C code nodes.
  */
 struct _ValaCCodeFragment {
-	ValaCCodeNode parent;
+	ValaCCodeNode parent_instance;
 	ValaCCodeFragmentPrivate * priv;
 };
 struct _ValaCCodeFragmentClass {
-	ValaCCodeNodeClass parent;
+	ValaCCodeNodeClass parent_class;
 };
 
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node);
 GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
+ValaCCodeFragment* vala_ccode_fragment_new (void);
 GType vala_ccode_fragment_get_type (void);
 
+
 G_END_DECLS
 
 #endif
