@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACCODEONCESECTION_H__
-#define __VALACCODEONCESECTION_H__
+#ifndef __CCODE_VALACCODEONCESECTION_H__
+#define __CCODE_VALACCODEONCESECTION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -48,17 +48,18 @@ typedef struct _ValaCCodeOnceSectionPrivate ValaCCodeOnceSectionPrivate;
  * Represents a section that should only to processed once.
  */
 struct _ValaCCodeOnceSection {
-	ValaCCodeFragment parent;
+	ValaCCodeFragment parent_instance;
 	ValaCCodeOnceSectionPrivate * priv;
 };
 struct _ValaCCodeOnceSectionClass {
-	ValaCCodeFragmentClass parent;
+	ValaCCodeFragmentClass parent_class;
 };
 
 ValaCCodeOnceSection* vala_ccode_once_section_new (const char* def);
 char* vala_ccode_once_section_get_define (ValaCCodeOnceSection* self);
 void vala_ccode_once_section_set_define (ValaCCodeOnceSection* self, const char* value);
-GType vala_ccode_once_section_get_type ();
+GType vala_ccode_once_section_get_type (void);
+
 
 G_END_DECLS
 
