@@ -46,15 +46,16 @@ static void vala_ccode_variable_declarator_dispose (GObject * obj);
 
 
 
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* _name) {
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeVariableDeclarator * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
 	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _name);
+	g_value_set_string (&__params_it->value, name);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
 	while (__params_it > __params) {
@@ -66,19 +67,20 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* _na
 }
 
 
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer (const char* _name, ValaCCodeExpression* init) {
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer (const char* name, ValaCCodeExpression* initializer) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeVariableDeclarator * self;
-	g_return_val_if_fail (init == NULL || VALA_IS_CCODE_EXPRESSION (init), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (initializer == NULL || VALA_IS_CCODE_EXPRESSION (initializer), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
 	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _name);
+	g_value_set_string (&__params_it->value, name);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_CCODE_VARIABLE_DECLARATOR, __params_it - __params, __params);
-	vala_ccode_variable_declarator_set_initializer (self, init);
+	vala_ccode_variable_declarator_set_initializer (self, initializer);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -91,7 +93,7 @@ ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new_with_initializer
 static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	if (self->priv->_initializer != NULL) {
 		vala_ccode_writer_write_string (writer, " = ");
@@ -103,7 +105,7 @@ static void vala_ccode_variable_declarator_real_write (ValaCCodeNode* base, Vala
 static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	/* initializer lists can't be moved to a separate statement*/
 	if (VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer)) {
@@ -116,7 +118,7 @@ static void vala_ccode_variable_declarator_real_write_declaration (ValaCCodeNode
 static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeDeclarator* base, ValaCCodeWriter* writer) {
 	ValaCCodeVariableDeclarator * self;
 	self = VALA_CCODE_VARIABLE_DECLARATOR (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (self->priv->_initializer != NULL && !(VALA_IS_CCODE_INITIALIZER_LIST (self->priv->_initializer))) {
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 		vala_ccode_writer_write_string (writer, self->priv->_name);
