@@ -47,7 +47,6 @@
 #include <ccode/valaccodebinaryexpression.h>
 #include <ccode/valaccodeparenthesizedexpression.h>
 #include <ccode/valaccodeelementaccess.h>
-#include <gobject/valaccodebinding.h>
 #include <gobject/valaccodegenerator.h>
 
 
@@ -61,24 +60,24 @@ enum  {
 	VALA_CCODE_ELEMENT_ACCESS_BINDING_DUMMY_PROPERTY,
 	VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS
 };
-static void vala_ccode_element_access_binding_real_emit (ValaCodeBinding* base);
+static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base);
 static gpointer vala_ccode_element_access_binding_parent_class = NULL;
 static void vala_ccode_element_access_binding_dispose (GObject * obj);
 
 
 
-ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCodeGenerator* codegen, ValaElementAccess* element_access) {
+ValaCCodeElementAccessBinding* vala_ccode_element_access_binding_new (ValaCCodeGenerator* codegen, ValaElementAccess* element_access) {
 	ValaCCodeElementAccessBinding * self;
-	g_return_val_if_fail (codegen == NULL || VALA_IS_CODE_GENERATOR (codegen), NULL);
-	g_return_val_if_fail (element_access == NULL || VALA_IS_ELEMENT_ACCESS (element_access), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_GENERATOR (codegen), NULL);
+	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (element_access), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS_BINDING, 0, NULL);
-	vala_ccode_binding_set_codegen (VALA_CCODE_BINDING (self), VALA_CCODE_GENERATOR (codegen));
 	vala_ccode_element_access_binding_set_element_access (self, element_access);
+	vala_ccode_binding_set_codegen (VALA_CCODE_BINDING (self), codegen);
 	return self;
 }
 
 
-static void vala_ccode_element_access_binding_real_emit (ValaCodeBinding* base) {
+static void vala_ccode_element_access_binding_real_emit (ValaCCodeBinding* base) {
 	ValaCCodeElementAccessBinding * self;
 	ValaElementAccess* _tmp0;
 	ValaElementAccess* expr;
@@ -149,82 +148,100 @@ static void vala_ccode_element_access_binding_real_emit (ValaCodeBinding* base)
 			(coffsetcall == NULL ? NULL : (coffsetcall = (g_object_unref (coffsetcall), NULL)));
 			(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 		} else {
-			if (container_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type != NULL && (vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type) || vala_typesymbol_is_subtype_of (container_type, vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type))) {
+			if (container_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type != NULL && vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type != NULL && (vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type)) || vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type)))) {
+				ValaTypesymbol* collection_iface;
 				ValaMethod* get_method;
 				GeeCollection* get_params;
 				GeeIterator* get_params_it;
 				ValaFormalParameter* get_param;
-				ValaCCodeIdentifier* _tmp16;
-				char* _tmp15;
-				ValaCCodeFunctionCall* _tmp17;
-				ValaCCodeFunctionCall* get_ccall;
-				ValaCCodeCastExpression* _tmp20;
+				ValaCCodeIdentifier* _tmp20;
 				char* _tmp19;
-				char* _tmp18;
-				ValaCCodeExpression* _tmp21;
-				get_method = VALA_METHOD (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (container_type)), "get"));
+				ValaCCodeFunctionCall* _tmp21;
+				ValaCCodeFunctionCall* get_ccall;
+				ValaCCodeCastExpression* _tmp24;
+				char* _tmp23;
+				char* _tmp22;
+				ValaCCodeExpression* _tmp25;
+				collection_iface = NULL;
+				if (vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type))) {
+					ValaTypesymbol* _tmp15;
+					ValaInterface* _tmp14;
+					_tmp15 = NULL;
+					_tmp14 = NULL;
+					collection_iface = (_tmp15 = VALA_TYPESYMBOL ((_tmp14 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->list_type, (_tmp14 == NULL ? NULL : g_object_ref (_tmp14)))), (collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL))), _tmp15);
+				} else {
+					if (vala_typesymbol_is_subtype_of (container_type, VALA_TYPESYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type))) {
+						ValaTypesymbol* _tmp17;
+						ValaInterface* _tmp16;
+						_tmp17 = NULL;
+						_tmp16 = NULL;
+						collection_iface = (_tmp17 = VALA_TYPESYMBOL ((_tmp16 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->map_type, (_tmp16 == NULL ? NULL : g_object_ref (_tmp16)))), (collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL))), _tmp17);
+					}
+				}
+				get_method = VALA_METHOD (vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (collection_iface)), "get"));
 				get_params = vala_method_get_parameters (get_method);
 				get_params_it = gee_iterable_iterator (GEE_ITERABLE (get_params));
 				gee_iterator_next (get_params_it);
 				get_param = ((ValaFormalParameter*) gee_iterator_get (get_params_it));
 				if (vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (get_param)) != NULL) {
 					ValaDataType* index_type;
-					ValaCCodeExpression* _tmp14;
+					ValaCCodeExpression* _tmp18;
 					index_type = vala_semantic_analyzer_get_actual_type (vala_expression_get_static_type (vala_element_access_get_container (expr)), VALA_SYMBOL (get_method), vala_formal_parameter_get_type_reference (get_param), VALA_CODE_NODE (expr));
-					_tmp14 = NULL;
-					cindex = (_tmp14 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp14);
+					_tmp18 = NULL;
+					cindex = (_tmp18 = vala_ccode_generator_convert_to_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), cindex, index_type), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp18);
 					(index_type == NULL ? NULL : (index_type = (g_object_unref (index_type), NULL)));
 				}
-				_tmp16 = NULL;
-				_tmp15 = NULL;
-				_tmp17 = NULL;
-				get_ccall = (_tmp17 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp16 = vala_ccode_identifier_new ((_tmp15 = vala_method_get_cname (get_method)))))), (_tmp16 == NULL ? NULL : (_tmp16 = (g_object_unref (_tmp16), NULL))), (_tmp15 = (g_free (_tmp15), NULL)), _tmp17);
 				_tmp20 = NULL;
 				_tmp19 = NULL;
-				_tmp18 = NULL;
-				vala_ccode_function_call_add_argument (get_ccall, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_cast_expression_new (ccontainer, (_tmp19 = g_strconcat ((_tmp18 = vala_typesymbol_get_cname (container_type, FALSE)), "*", NULL))))));
-				(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
-				_tmp19 = (g_free (_tmp19), NULL);
-				_tmp18 = (g_free (_tmp18), NULL);
-				vala_ccode_function_call_add_argument (get_ccall, cindex);
 				_tmp21 = NULL;
-				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp21 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (get_ccall), vala_expression_get_static_type (VALA_EXPRESSION (expr)))));
-				(_tmp21 == NULL ? NULL : (_tmp21 = (g_object_unref (_tmp21), NULL)));
+				get_ccall = (_tmp21 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ((_tmp19 = vala_method_get_cname (get_method)))))), (_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL))), (_tmp19 = (g_free (_tmp19), NULL)), _tmp21);
+				_tmp24 = NULL;
+				_tmp23 = NULL;
+				_tmp22 = NULL;
+				vala_ccode_function_call_add_argument (get_ccall, VALA_CCODE_EXPRESSION ((_tmp24 = vala_ccode_cast_expression_new (ccontainer, (_tmp23 = g_strconcat ((_tmp22 = vala_typesymbol_get_cname (collection_iface, FALSE)), "*", NULL))))));
+				(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
+				_tmp23 = (g_free (_tmp23), NULL);
+				_tmp22 = (g_free (_tmp22), NULL);
+				vala_ccode_function_call_add_argument (get_ccall, cindex);
+				_tmp25 = NULL;
+				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), (_tmp25 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (get_ccall), vala_expression_get_static_type (VALA_EXPRESSION (expr)))));
+				(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+				(collection_iface == NULL ? NULL : (collection_iface = (g_object_unref (collection_iface), NULL)));
 				(get_method == NULL ? NULL : (get_method = (g_object_unref (get_method), NULL)));
 				(get_params == NULL ? NULL : (get_params = (g_object_unref (get_params), NULL)));
 				(get_params_it == NULL ? NULL : (get_params_it = (g_object_unref (get_params_it), NULL)));
 				(get_param == NULL ? NULL : (get_param = (g_object_unref (get_param), NULL)));
 				(get_ccall == NULL ? NULL : (get_ccall = (g_object_unref (get_ccall), NULL)));
 			} else {
-				ValaCCodeElementAccess* _tmp28;
+				ValaCCodeElementAccess* _tmp32;
 				{
 					gint i;
-					i = 0;
-					for (i = 1; i < rank; i++) {
-						ValaCCodeExpression* _tmp23;
-						ValaCCodeParenthesizedExpression* _tmp22;
-						ValaCCodeBinaryExpression* _tmp24;
-						ValaCCodeBinaryExpression* cmul;
+					/* access to element in an array*/
+					i = 1;
+					for (; i < rank; i++) {
 						ValaCCodeExpression* _tmp27;
 						ValaCCodeParenthesizedExpression* _tmp26;
-						ValaExpression* _tmp25;
-						/* access to element in an array*/
-						_tmp23 = NULL;
-						_tmp22 = NULL;
-						_tmp24 = NULL;
-						cmul = (_tmp24 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp23 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL))), (_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL))), _tmp24);
+						ValaCCodeBinaryExpression* _tmp28;
+						ValaCCodeBinaryExpression* cmul;
+						ValaCCodeExpression* _tmp31;
+						ValaCCodeParenthesizedExpression* _tmp30;
+						ValaExpression* _tmp29;
 						_tmp27 = NULL;
 						_tmp26 = NULL;
-						_tmp25 = NULL;
-						cindex = (_tmp27 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp25 = ((ValaExpression*) gee_list_get (((GeeList*) indices), i))))))))))), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp27);
-						(_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL)));
-						(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+						_tmp28 = NULL;
+						cmul = (_tmp28 = vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_MUL, VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_parenthesized_expression_new (cindex))), (_tmp27 = vala_ccode_generator_get_array_length_cexpression (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_element_access_get_container (expr), i + 1))), (_tmp27 == NULL ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL))), (_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL))), _tmp28);
+						_tmp31 = NULL;
+						_tmp30 = NULL;
+						_tmp29 = NULL;
+						cindex = (_tmp31 = VALA_CCODE_EXPRESSION (vala_ccode_binary_expression_new (VALA_CCODE_BINARY_OPERATOR_PLUS, VALA_CCODE_EXPRESSION (cmul), VALA_CCODE_EXPRESSION ((_tmp30 = vala_ccode_parenthesized_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE ((_tmp29 = ((ValaExpression*) gee_list_get (((GeeList*) indices), i))))))))))), (cindex == NULL ? NULL : (cindex = (g_object_unref (cindex), NULL))), _tmp31);
+						(_tmp30 == NULL ? NULL : (_tmp30 = (g_object_unref (_tmp30), NULL)));
+						(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
 						(cmul == NULL ? NULL : (cmul = (g_object_unref (cmul), NULL)));
 					}
 				}
-				_tmp28 = NULL;
-				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION ((_tmp28 = vala_ccode_element_access_new (ccontainer, cindex))));
-				(_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL)));
+				_tmp32 = NULL;
+				vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION ((_tmp32 = vala_ccode_element_access_new (ccontainer, cindex))));
+				(_tmp32 == NULL ? NULL : (_tmp32 = (g_object_unref (_tmp32), NULL)));
 			}
 		}
 	}
@@ -288,7 +305,7 @@ static void vala_ccode_element_access_binding_class_init (ValaCCodeElementAccess
 	G_OBJECT_CLASS (klass)->get_property = vala_ccode_element_access_binding_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_ccode_element_access_binding_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_element_access_binding_dispose;
-	VALA_CODE_BINDING_CLASS (klass)->emit = vala_ccode_element_access_binding_real_emit;
+	VALA_CCODE_BINDING_CLASS (klass)->emit = vala_ccode_element_access_binding_real_emit;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_ELEMENT_ACCESS_BINDING_ELEMENT_ACCESS, g_param_spec_object ("element-access", "element-access", "element-access", VALA_TYPE_ELEMENT_ACCESS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
