@@ -22,24 +22,27 @@
 
 #include <vala/valacatchclause.h>
 #include <vala/valablock.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaCatchClausePrivate {
 	char* _variable_name;
 	ValaBlock* _body;
-	ValaVariableDeclarator* _variable_declarator;
+	ValaLocalVariable* _error_variable;
 	ValaDataType* _data_type;
 };
 #define VALA_CATCH_CLAUSE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CATCH_CLAUSE, ValaCatchClausePrivate))
 enum  {
 	VALA_CATCH_CLAUSE_DUMMY_PROPERTY,
-	VALA_CATCH_CLAUSE_TYPE_REFERENCE,
+	VALA_CATCH_CLAUSE_ERROR_TYPE,
 	VALA_CATCH_CLAUSE_VARIABLE_NAME,
 	VALA_CATCH_CLAUSE_BODY,
-	VALA_CATCH_CLAUSE_VARIABLE_DECLARATOR
+	VALA_CATCH_CLAUSE_ERROR_VARIABLE
 };
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -48,6 +51,7 @@ static gpointer vala_catch_clause_parent_class = NULL;
 static void vala_catch_clause_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new catch clause.
  *
@@ -57,13 +61,14 @@ static void vala_catch_clause_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created catch clause
  */
-ValaCatchClause* vala_catch_clause_new (ValaDataType* type_reference, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
+ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaCatchClause * self;
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (error_type == NULL || VALA_IS_DATA_TYPE (error_type), NULL);
+	g_return_val_if_fail (variable_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_CATCH_CLAUSE, 0, NULL);
-	vala_catch_clause_set_type_reference (self, type_reference);
+	vala_catch_clause_set_error_type (self, error_type);
 	vala_catch_clause_set_variable_name (self, variable_name);
 	vala_catch_clause_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -74,7 +79,7 @@ ValaCatchClause* vala_catch_clause_new (ValaDataType* type_reference, const char
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_catch_clause (visitor, self);
 }
 
@@ -82,32 +87,32 @@ static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	if (vala_catch_clause_get_type_reference (self) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_catch_clause_get_type_reference (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	if (vala_catch_clause_get_error_type (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_catch_clause_get_error_type (self)), visitor);
 	}
-	vala_code_node_accept (VALA_CODE_NODE (vala_catch_clause_get_body (self)), visitor);
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 }
 
 
 static void vala_catch_clause_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
-	if (vala_catch_clause_get_type_reference (self) == old_type) {
-		vala_catch_clause_set_type_reference (self, new_type);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_catch_clause_get_error_type (self) == old_type) {
+		vala_catch_clause_set_error_type (self, new_type);
 	}
 }
 
 
-ValaDataType* vala_catch_clause_get_type_reference (ValaCatchClause* self) {
+ValaDataType* vala_catch_clause_get_error_type (ValaCatchClause* self) {
 	g_return_val_if_fail (VALA_IS_CATCH_CLAUSE (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_catch_clause_set_type_reference (ValaCatchClause* self, ValaDataType* value) {
+void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
@@ -152,19 +157,19 @@ void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value) {
 }
 
 
-ValaVariableDeclarator* vala_catch_clause_get_variable_declarator (ValaCatchClause* self) {
+ValaLocalVariable* vala_catch_clause_get_error_variable (ValaCatchClause* self) {
 	g_return_val_if_fail (VALA_IS_CATCH_CLAUSE (self), NULL);
-	return self->priv->_variable_declarator;
+	return self->priv->_error_variable;
 }
 
 
-void vala_catch_clause_set_variable_declarator (ValaCatchClause* self, ValaVariableDeclarator* value) {
-	ValaVariableDeclarator* _tmp2;
-	ValaVariableDeclarator* _tmp1;
+void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVariable* value) {
+	ValaLocalVariable* _tmp2;
+	ValaLocalVariable* _tmp1;
 	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL))), _tmp2);
+	self->priv->_error_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (g_object_unref (self->priv->_error_variable), NULL))), _tmp2);
 }
 
 
@@ -172,8 +177,8 @@ static void vala_catch_clause_get_property (GObject * object, guint property_id,
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (object);
 	switch (property_id) {
-		case VALA_CATCH_CLAUSE_TYPE_REFERENCE:
-		g_value_set_object (value, vala_catch_clause_get_type_reference (self));
+		case VALA_CATCH_CLAUSE_ERROR_TYPE:
+		g_value_set_object (value, vala_catch_clause_get_error_type (self));
 		break;
 		case VALA_CATCH_CLAUSE_VARIABLE_NAME:
 		g_value_set_string (value, vala_catch_clause_get_variable_name (self));
@@ -181,8 +186,8 @@ static void vala_catch_clause_get_property (GObject * object, guint property_id,
 		case VALA_CATCH_CLAUSE_BODY:
 		g_value_set_object (value, vala_catch_clause_get_body (self));
 		break;
-		case VALA_CATCH_CLAUSE_VARIABLE_DECLARATOR:
-		g_value_set_object (value, vala_catch_clause_get_variable_declarator (self));
+		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
+		g_value_set_object (value, vala_catch_clause_get_error_variable (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -195,8 +200,8 @@ static void vala_catch_clause_set_property (GObject * object, guint property_id,
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (object);
 	switch (property_id) {
-		case VALA_CATCH_CLAUSE_TYPE_REFERENCE:
-		vala_catch_clause_set_type_reference (self, g_value_get_object (value));
+		case VALA_CATCH_CLAUSE_ERROR_TYPE:
+		vala_catch_clause_set_error_type (self, g_value_get_object (value));
 		break;
 		case VALA_CATCH_CLAUSE_VARIABLE_NAME:
 		vala_catch_clause_set_variable_name (self, g_value_get_string (value));
@@ -204,8 +209,8 @@ static void vala_catch_clause_set_property (GObject * object, guint property_id,
 		case VALA_CATCH_CLAUSE_BODY:
 		vala_catch_clause_set_body (self, g_value_get_object (value));
 		break;
-		case VALA_CATCH_CLAUSE_VARIABLE_DECLARATOR:
-		vala_catch_clause_set_variable_declarator (self, g_value_get_object (value));
+		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
+		vala_catch_clause_set_error_variable (self, g_value_get_object (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -223,10 +228,10 @@ static void vala_catch_clause_class_init (ValaCatchClauseClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_catch_clause_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_catch_clause_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_catch_clause_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_ERROR_TYPE, g_param_spec_object ("error-type", "error-type", "error-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_VARIABLE_NAME, g_param_spec_string ("variable-name", "variable-name", "variable-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_VARIABLE_DECLARATOR, g_param_spec_object ("variable-declarator", "variable-declarator", "variable-declarator", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_ERROR_VARIABLE, g_param_spec_object ("error-variable", "error-variable", "error-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -240,7 +245,7 @@ static void vala_catch_clause_dispose (GObject * obj) {
 	self = VALA_CATCH_CLAUSE (obj);
 	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL)));
+	(self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (g_object_unref (self->priv->_error_variable), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_catch_clause_parent_class)->dispose (obj);
 }
