@@ -50,8 +50,7 @@
 #include <vala/valablock.h>
 #include <vala/valaemptystatement.h>
 #include <vala/valadeclarationstatement.h>
-#include <vala/valalocalvariabledeclaration.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
 #include <vala/valaifstatement.h>
@@ -132,8 +131,7 @@ static void vala_code_visitor_real_visit_data_type (ValaCodeVisitor* self, ValaD
 static void vala_code_visitor_real_visit_block (ValaCodeVisitor* self, ValaBlock* b);
 static void vala_code_visitor_real_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt);
 static void vala_code_visitor_real_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt);
-static void vala_code_visitor_real_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl);
-static void vala_code_visitor_real_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl);
+static void vala_code_visitor_real_visit_local_variable (ValaCodeVisitor* self, ValaLocalVariable* local);
 static void vala_code_visitor_real_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list);
 static void vala_code_visitor_real_visit_expression_statement (ValaCodeVisitor* self, ValaExpressionStatement* stmt);
 static void vala_code_visitor_real_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt);
@@ -190,7 +188,7 @@ static gpointer vala_code_visitor_parent_class = NULL;
  */
 static void vala_code_visitor_real_visit_source_file (ValaCodeVisitor* self, ValaSourceFile* source_file) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (source_file == NULL || VALA_IS_SOURCE_FILE (source_file));
+	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
 }
 
 
@@ -206,7 +204,7 @@ void vala_code_visitor_visit_source_file (ValaCodeVisitor* self, ValaSourceFile*
  */
 static void vala_code_visitor_real_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE (ns));
+	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 }
 
 
@@ -222,7 +220,7 @@ void vala_code_visitor_visit_namespace (ValaCodeVisitor* self, ValaNamespace* ns
  */
 static void vala_code_visitor_real_visit_class (ValaCodeVisitor* self, ValaClass* cl) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 }
 
 
@@ -238,7 +236,7 @@ void vala_code_visitor_visit_class (ValaCodeVisitor* self, ValaClass* cl) {
  */
 static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStruct* st) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 }
 
 
@@ -254,7 +252,7 @@ void vala_code_visitor_visit_struct (ValaCodeVisitor* self, ValaStruct* st) {
  */
 static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
 }
 
 
@@ -270,7 +268,7 @@ void vala_code_visitor_visit_interface (ValaCodeVisitor* self, ValaInterface* if
  */
 static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	g_return_if_fail (VALA_IS_ENUM (en));
 }
 
 
@@ -286,7 +284,7 @@ void vala_code_visitor_visit_enum (ValaCodeVisitor* self, ValaEnum* en) {
  */
 static void vala_code_visitor_real_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (ev == NULL || VALA_IS_ENUM_VALUE (ev));
+	g_return_if_fail (VALA_IS_ENUM_VALUE (ev));
 }
 
 
@@ -302,7 +300,7 @@ void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* e
  */
 static void vala_code_visitor_real_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomain* edomain) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (edomain == NULL || VALA_IS_ERROR_DOMAIN (edomain));
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (edomain));
 }
 
 
@@ -318,7 +316,7 @@ void vala_code_visitor_visit_error_domain (ValaCodeVisitor* self, ValaErrorDomai
  */
 static void vala_code_visitor_real_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* ecode) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (ecode == NULL || VALA_IS_ERROR_CODE (ecode));
+	g_return_if_fail (VALA_IS_ERROR_CODE (ecode));
 }
 
 
@@ -334,7 +332,7 @@ void vala_code_visitor_visit_error_code (ValaCodeVisitor* self, ValaErrorCode* e
  */
 static void vala_code_visitor_real_visit_delegate (ValaCodeVisitor* self, ValaDelegate* d) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	g_return_if_fail (VALA_IS_DELEGATE (d));
 }
 
 
@@ -350,7 +348,7 @@ void vala_code_visitor_visit_delegate (ValaCodeVisitor* self, ValaDelegate* d) {
  */
 static void vala_code_visitor_real_visit_member (ValaCodeVisitor* self, ValaMember* m) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (m == NULL || VALA_IS_MEMBER (m));
+	g_return_if_fail (VALA_IS_MEMBER (m));
 }
 
 
@@ -366,7 +364,7 @@ void vala_code_visitor_visit_member (ValaCodeVisitor* self, ValaMember* m) {
  */
 static void vala_code_visitor_real_visit_constant (ValaCodeVisitor* self, ValaConstant* c) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	g_return_if_fail (VALA_IS_CONSTANT (c));
 }
 
 
@@ -382,7 +380,7 @@ void vala_code_visitor_visit_constant (ValaCodeVisitor* self, ValaConstant* c) {
  */
 static void vala_code_visitor_real_visit_field (ValaCodeVisitor* self, ValaField* f) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 }
 
 
@@ -398,7 +396,7 @@ void vala_code_visitor_visit_field (ValaCodeVisitor* self, ValaField* f) {
  */
 static void vala_code_visitor_real_visit_method (ValaCodeVisitor* self, ValaMethod* m) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 }
 
 
@@ -414,7 +412,7 @@ void vala_code_visitor_visit_method (ValaCodeVisitor* self, ValaMethod* m) {
  */
 static void vala_code_visitor_real_visit_creation_method (ValaCodeVisitor* self, ValaCreationMethod* m) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 }
 
 
@@ -430,7 +428,7 @@ void vala_code_visitor_visit_creation_method (ValaCodeVisitor* self, ValaCreatio
  */
 static void vala_code_visitor_real_visit_formal_parameter (ValaCodeVisitor* self, ValaFormalParameter* p) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (p == NULL || VALA_IS_FORMAL_PARAMETER (p));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (p));
 }
 
 
@@ -446,7 +444,7 @@ void vala_code_visitor_visit_formal_parameter (ValaCodeVisitor* self, ValaFormal
  */
 static void vala_code_visitor_real_visit_property (ValaCodeVisitor* self, ValaProperty* prop) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 }
 
 
@@ -462,7 +460,7 @@ void vala_code_visitor_visit_property (ValaCodeVisitor* self, ValaProperty* prop
  */
 static void vala_code_visitor_real_visit_property_accessor (ValaCodeVisitor* self, ValaPropertyAccessor* acc) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (acc == NULL || VALA_IS_PROPERTY_ACCESSOR (acc));
+	g_return_if_fail (VALA_IS_PROPERTY_ACCESSOR (acc));
 }
 
 
@@ -478,7 +476,7 @@ void vala_code_visitor_visit_property_accessor (ValaCodeVisitor* self, ValaPrope
  */
 static void vala_code_visitor_real_visit_signal (ValaCodeVisitor* self, ValaSignal* sig) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 }
 
 
@@ -494,7 +492,7 @@ void vala_code_visitor_visit_signal (ValaCodeVisitor* self, ValaSignal* sig) {
  */
 static void vala_code_visitor_real_visit_constructor (ValaCodeVisitor* self, ValaConstructor* c) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (c == NULL || VALA_IS_CONSTRUCTOR (c));
+	g_return_if_fail (VALA_IS_CONSTRUCTOR (c));
 }
 
 
@@ -510,7 +508,7 @@ void vala_code_visitor_visit_constructor (ValaCodeVisitor* self, ValaConstructor
  */
 static void vala_code_visitor_real_visit_destructor (ValaCodeVisitor* self, ValaDestructor* d) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (d == NULL || VALA_IS_DESTRUCTOR (d));
+	g_return_if_fail (VALA_IS_DESTRUCTOR (d));
 }
 
 
@@ -526,7 +524,7 @@ void vala_code_visitor_visit_destructor (ValaCodeVisitor* self, ValaDestructor*
  */
 static void vala_code_visitor_real_visit_named_argument (ValaCodeVisitor* self, ValaNamedArgument* n) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (n == NULL || VALA_IS_NAMED_ARGUMENT (n));
+	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (n));
 }
 
 
@@ -542,7 +540,7 @@ void vala_code_visitor_visit_named_argument (ValaCodeVisitor* self, ValaNamedArg
  */
 static void vala_code_visitor_real_visit_type_parameter (ValaCodeVisitor* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 }
 
 
@@ -558,7 +556,7 @@ void vala_code_visitor_visit_type_parameter (ValaCodeVisitor* self, ValaTypePara
  */
 static void vala_code_visitor_real_visit_namespace_reference (ValaCodeVisitor* self, ValaNamespaceReference* ns) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE_REFERENCE (ns));
+	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
 }
 
 
@@ -574,7 +572,7 @@ void vala_code_visitor_visit_namespace_reference (ValaCodeVisitor* self, ValaNam
  */
 static void vala_code_visitor_real_visit_data_type (ValaCodeVisitor* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 }
 
 
@@ -590,7 +588,7 @@ void vala_code_visitor_visit_data_type (ValaCodeVisitor* self, ValaDataType* typ
  */
 static void vala_code_visitor_real_visit_block (ValaCodeVisitor* self, ValaBlock* b) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (b == NULL || VALA_IS_BLOCK (b));
+	g_return_if_fail (VALA_IS_BLOCK (b));
 }
 
 
@@ -606,7 +604,7 @@ void vala_code_visitor_visit_block (ValaCodeVisitor* self, ValaBlock* b) {
  */
 static void vala_code_visitor_real_visit_empty_statement (ValaCodeVisitor* self, ValaEmptyStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_EMPTY_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_EMPTY_STATEMENT (stmt));
 }
 
 
@@ -622,7 +620,7 @@ void vala_code_visitor_visit_empty_statement (ValaCodeVisitor* self, ValaEmptySt
  */
 static void vala_code_visitor_real_visit_declaration_statement (ValaCodeVisitor* self, ValaDeclarationStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_DECLARATION_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_DECLARATION_STATEMENT (stmt));
 }
 
 
@@ -632,34 +630,18 @@ void vala_code_visitor_visit_declaration_statement (ValaCodeVisitor* self, ValaD
 
 
 /**
- * Visit operation called for local variable declarations.
+ * Visit operation called for local variables.
  *
- * @param decl a local variable declaration
+ * @param local a local variable
  */
-static void vala_code_visitor_real_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl) {
+static void vala_code_visitor_real_visit_local_variable (ValaCodeVisitor* self, ValaLocalVariable* local) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (decl == NULL || VALA_IS_LOCAL_VARIABLE_DECLARATION (decl));
+	g_return_if_fail (VALA_IS_LOCAL_VARIABLE (local));
 }
 
 
-void vala_code_visitor_visit_local_variable_declaration (ValaCodeVisitor* self, ValaLocalVariableDeclaration* decl) {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_local_variable_declaration (self, decl);
-}
-
-
-/**
- * Visit operation called for variable declarators.
- *
- * @param decl a variable declarator
- */
-static void vala_code_visitor_real_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl) {
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (decl == NULL || VALA_IS_VARIABLE_DECLARATOR (decl));
-}
-
-
-void vala_code_visitor_visit_variable_declarator (ValaCodeVisitor* self, ValaVariableDeclarator* decl) {
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_variable_declarator (self, decl);
+void vala_code_visitor_visit_local_variable (ValaCodeVisitor* self, ValaLocalVariable* local) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_local_variable (self, local);
 }
 
 
@@ -670,7 +652,7 @@ void vala_code_visitor_visit_variable_declarator (ValaCodeVisitor* self, ValaVar
  */
 static void vala_code_visitor_real_visit_initializer_list (ValaCodeVisitor* self, ValaInitializerList* list) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (list == NULL || VALA_IS_INITIALIZER_LIST (list));
+	g_return_if_fail (VALA_IS_INITIALIZER_LIST (list));
 }
 
 
@@ -686,7 +668,7 @@ void vala_code_visitor_visit_initializer_list (ValaCodeVisitor* self, ValaInitia
  */
 static void vala_code_visitor_real_visit_expression_statement (ValaCodeVisitor* self, ValaExpressionStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_EXPRESSION_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_EXPRESSION_STATEMENT (stmt));
 }
 
 
@@ -702,7 +684,7 @@ void vala_code_visitor_visit_expression_statement (ValaCodeVisitor* self, ValaEx
  */
 static void vala_code_visitor_real_visit_if_statement (ValaCodeVisitor* self, ValaIfStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_IF_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_IF_STATEMENT (stmt));
 }
 
 
@@ -718,7 +700,7 @@ void vala_code_visitor_visit_if_statement (ValaCodeVisitor* self, ValaIfStatemen
  */
 static void vala_code_visitor_real_visit_switch_statement (ValaCodeVisitor* self, ValaSwitchStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_SWITCH_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_SWITCH_STATEMENT (stmt));
 }
 
 
@@ -734,7 +716,7 @@ void vala_code_visitor_visit_switch_statement (ValaCodeVisitor* self, ValaSwitch
  */
 static void vala_code_visitor_real_visit_switch_section (ValaCodeVisitor* self, ValaSwitchSection* section) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (section == NULL || VALA_IS_SWITCH_SECTION (section));
+	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
 }
 
 
@@ -750,7 +732,7 @@ void vala_code_visitor_visit_switch_section (ValaCodeVisitor* self, ValaSwitchSe
  */
 static void vala_code_visitor_real_visit_switch_label (ValaCodeVisitor* self, ValaSwitchLabel* label) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (label == NULL || VALA_IS_SWITCH_LABEL (label));
+	g_return_if_fail (VALA_IS_SWITCH_LABEL (label));
 }
 
 
@@ -766,7 +748,7 @@ void vala_code_visitor_visit_switch_label (ValaCodeVisitor* self, ValaSwitchLabe
  */
 static void vala_code_visitor_real_visit_while_statement (ValaCodeVisitor* self, ValaWhileStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_WHILE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_WHILE_STATEMENT (stmt));
 }
 
 
@@ -782,7 +764,7 @@ void vala_code_visitor_visit_while_statement (ValaCodeVisitor* self, ValaWhileSt
  */
 static void vala_code_visitor_real_visit_do_statement (ValaCodeVisitor* self, ValaDoStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_DO_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_DO_STATEMENT (stmt));
 }
 
 
@@ -798,7 +780,7 @@ void vala_code_visitor_visit_do_statement (ValaCodeVisitor* self, ValaDoStatemen
  */
 static void vala_code_visitor_real_visit_for_statement (ValaCodeVisitor* self, ValaForStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_FOR_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOR_STATEMENT (stmt));
 }
 
 
@@ -814,7 +796,7 @@ void vala_code_visitor_visit_for_statement (ValaCodeVisitor* self, ValaForStatem
  */
 static void vala_code_visitor_real_visit_foreach_statement (ValaCodeVisitor* self, ValaForeachStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_FOREACH_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (stmt));
 }
 
 
@@ -830,7 +812,7 @@ void vala_code_visitor_visit_foreach_statement (ValaCodeVisitor* self, ValaForea
  */
 static void vala_code_visitor_real_visit_break_statement (ValaCodeVisitor* self, ValaBreakStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_BREAK_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_BREAK_STATEMENT (stmt));
 }
 
 
@@ -846,7 +828,7 @@ void vala_code_visitor_visit_break_statement (ValaCodeVisitor* self, ValaBreakSt
  */
 static void vala_code_visitor_real_visit_continue_statement (ValaCodeVisitor* self, ValaContinueStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_CONTINUE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_CONTINUE_STATEMENT (stmt));
 }
 
 
@@ -862,7 +844,7 @@ void vala_code_visitor_visit_continue_statement (ValaCodeVisitor* self, ValaCont
  */
 static void vala_code_visitor_real_visit_return_statement (ValaCodeVisitor* self, ValaReturnStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_RETURN_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_RETURN_STATEMENT (stmt));
 }
 
 
@@ -878,7 +860,7 @@ void vala_code_visitor_visit_return_statement (ValaCodeVisitor* self, ValaReturn
  */
 static void vala_code_visitor_real_visit_throw_statement (ValaCodeVisitor* self, ValaThrowStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_THROW_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_THROW_STATEMENT (stmt));
 }
 
 
@@ -894,7 +876,7 @@ void vala_code_visitor_visit_throw_statement (ValaCodeVisitor* self, ValaThrowSt
  */
 static void vala_code_visitor_real_visit_try_statement (ValaCodeVisitor* self, ValaTryStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_TRY_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_TRY_STATEMENT (stmt));
 }
 
 
@@ -910,7 +892,7 @@ void vala_code_visitor_visit_try_statement (ValaCodeVisitor* self, ValaTryStatem
  */
 static void vala_code_visitor_real_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (clause == NULL || VALA_IS_CATCH_CLAUSE (clause));
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (clause));
 }
 
 
@@ -926,7 +908,7 @@ void vala_code_visitor_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClaus
  */
 static void vala_code_visitor_real_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_LOCK_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_LOCK_STATEMENT (stmt));
 }
 
 
@@ -942,7 +924,7 @@ void vala_code_visitor_visit_lock_statement (ValaCodeVisitor* self, ValaLockStat
  */
 static void vala_code_visitor_real_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_DELETE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_DELETE_STATEMENT (stmt));
 }
 
 
@@ -958,7 +940,7 @@ void vala_code_visitor_visit_delete_statement (ValaCodeVisitor* self, ValaDelete
  */
 static void vala_code_visitor_real_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_ARRAY_CREATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (expr));
 }
 
 
@@ -974,7 +956,7 @@ void vala_code_visitor_visit_array_creation_expression (ValaCodeVisitor* self, V
  */
 static void vala_code_visitor_real_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_BOOLEAN_LITERAL (lit));
+	g_return_if_fail (VALA_IS_BOOLEAN_LITERAL (lit));
 }
 
 
@@ -990,7 +972,7 @@ void vala_code_visitor_visit_boolean_literal (ValaCodeVisitor* self, ValaBoolean
  */
 static void vala_code_visitor_real_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_CHARACTER_LITERAL (lit));
+	g_return_if_fail (VALA_IS_CHARACTER_LITERAL (lit));
 }
 
 
@@ -1006,7 +988,7 @@ void vala_code_visitor_visit_character_literal (ValaCodeVisitor* self, ValaChara
  */
 static void vala_code_visitor_real_visit_integer_literal (ValaCodeVisitor* self, ValaIntegerLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_INTEGER_LITERAL (lit));
+	g_return_if_fail (VALA_IS_INTEGER_LITERAL (lit));
 }
 
 
@@ -1022,7 +1004,7 @@ void vala_code_visitor_visit_integer_literal (ValaCodeVisitor* self, ValaInteger
  */
 static void vala_code_visitor_real_visit_real_literal (ValaCodeVisitor* self, ValaRealLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_REAL_LITERAL (lit));
+	g_return_if_fail (VALA_IS_REAL_LITERAL (lit));
 }
 
 
@@ -1038,7 +1020,7 @@ void vala_code_visitor_visit_real_literal (ValaCodeVisitor* self, ValaRealLitera
  */
 static void vala_code_visitor_real_visit_string_literal (ValaCodeVisitor* self, ValaStringLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_STRING_LITERAL (lit));
+	g_return_if_fail (VALA_IS_STRING_LITERAL (lit));
 }
 
 
@@ -1054,7 +1036,7 @@ void vala_code_visitor_visit_string_literal (ValaCodeVisitor* self, ValaStringLi
  */
 static void vala_code_visitor_real_visit_null_literal (ValaCodeVisitor* self, ValaNullLiteral* lit) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (lit == NULL || VALA_IS_NULL_LITERAL (lit));
+	g_return_if_fail (VALA_IS_NULL_LITERAL (lit));
 }
 
 
@@ -1070,7 +1052,7 @@ void vala_code_visitor_visit_null_literal (ValaCodeVisitor* self, ValaNullLitera
  */
 static void vala_code_visitor_real_visit_parenthesized_expression (ValaCodeVisitor* self, ValaParenthesizedExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_PARENTHESIZED_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (expr));
 }
 
 
@@ -1086,7 +1068,7 @@ void vala_code_visitor_visit_parenthesized_expression (ValaCodeVisitor* self, Va
  */
 static void vala_code_visitor_real_visit_member_access (ValaCodeVisitor* self, ValaMemberAccess* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_MEMBER_ACCESS (expr));
+	g_return_if_fail (VALA_IS_MEMBER_ACCESS (expr));
 }
 
 
@@ -1102,7 +1084,7 @@ void vala_code_visitor_visit_member_access (ValaCodeVisitor* self, ValaMemberAcc
  */
 static void vala_code_visitor_real_visit_invocation_expression (ValaCodeVisitor* self, ValaInvocationExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_INVOCATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_INVOCATION_EXPRESSION (expr));
 }
 
 
@@ -1118,7 +1100,7 @@ void vala_code_visitor_visit_invocation_expression (ValaCodeVisitor* self, ValaI
  */
 static void vala_code_visitor_real_visit_element_access (ValaCodeVisitor* self, ValaElementAccess* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_ELEMENT_ACCESS (expr));
+	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (expr));
 }
 
 
@@ -1134,7 +1116,7 @@ void vala_code_visitor_visit_element_access (ValaCodeVisitor* self, ValaElementA
  */
 static void vala_code_visitor_real_visit_base_access (ValaCodeVisitor* self, ValaBaseAccess* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_BASE_ACCESS (expr));
+	g_return_if_fail (VALA_IS_BASE_ACCESS (expr));
 }
 
 
@@ -1150,7 +1132,7 @@ void vala_code_visitor_visit_base_access (ValaCodeVisitor* self, ValaBaseAccess*
  */
 static void vala_code_visitor_real_visit_postfix_expression (ValaCodeVisitor* self, ValaPostfixExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_POSTFIX_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_POSTFIX_EXPRESSION (expr));
 }
 
 
@@ -1166,7 +1148,7 @@ void vala_code_visitor_visit_postfix_expression (ValaCodeVisitor* self, ValaPost
  */
 static void vala_code_visitor_real_visit_object_creation_expression (ValaCodeVisitor* self, ValaObjectCreationExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_OBJECT_CREATION_EXPRESSION (expr));
 }
 
 
@@ -1182,7 +1164,7 @@ void vala_code_visitor_visit_object_creation_expression (ValaCodeVisitor* self,
  */
 static void vala_code_visitor_real_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeofExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_SIZEOF_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_SIZEOF_EXPRESSION (expr));
 }
 
 
@@ -1198,7 +1180,7 @@ void vala_code_visitor_visit_sizeof_expression (ValaCodeVisitor* self, ValaSizeo
  */
 static void vala_code_visitor_real_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeofExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_TYPEOF_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_TYPEOF_EXPRESSION (expr));
 }
 
 
@@ -1214,7 +1196,7 @@ void vala_code_visitor_visit_typeof_expression (ValaCodeVisitor* self, ValaTypeo
  */
 static void vala_code_visitor_real_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_UNARY_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_UNARY_EXPRESSION (expr));
 }
 
 
@@ -1230,7 +1212,7 @@ void vala_code_visitor_visit_unary_expression (ValaCodeVisitor* self, ValaUnaryE
  */
 static void vala_code_visitor_real_visit_cast_expression (ValaCodeVisitor* self, ValaCastExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CAST_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CAST_EXPRESSION (expr));
 }
 
 
@@ -1246,7 +1228,7 @@ void vala_code_visitor_visit_cast_expression (ValaCodeVisitor* self, ValaCastExp
  */
 static void vala_code_visitor_real_visit_pointer_indirection (ValaCodeVisitor* self, ValaPointerIndirection* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_POINTER_INDIRECTION (expr));
+	g_return_if_fail (VALA_IS_POINTER_INDIRECTION (expr));
 }
 
 
@@ -1262,7 +1244,7 @@ void vala_code_visitor_visit_pointer_indirection (ValaCodeVisitor* self, ValaPoi
  */
 static void vala_code_visitor_real_visit_addressof_expression (ValaCodeVisitor* self, ValaAddressofExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_ADDRESSOF_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_ADDRESSOF_EXPRESSION (expr));
 }
 
 
@@ -1278,7 +1260,7 @@ void vala_code_visitor_visit_addressof_expression (ValaCodeVisitor* self, ValaAd
  */
 static void vala_code_visitor_real_visit_reference_transfer_expression (ValaCodeVisitor* self, ValaReferenceTransferExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_REFERENCE_TRANSFER_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_REFERENCE_TRANSFER_EXPRESSION (expr));
 }
 
 
@@ -1294,7 +1276,7 @@ void vala_code_visitor_visit_reference_transfer_expression (ValaCodeVisitor* sel
  */
 static void vala_code_visitor_real_visit_binary_expression (ValaCodeVisitor* self, ValaBinaryExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_BINARY_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_BINARY_EXPRESSION (expr));
 }
 
 
@@ -1310,7 +1292,7 @@ void vala_code_visitor_visit_binary_expression (ValaCodeVisitor* self, ValaBinar
  */
 static void vala_code_visitor_real_visit_type_check (ValaCodeVisitor* self, ValaTypeCheck* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_TYPECHECK (expr));
+	g_return_if_fail (VALA_IS_TYPECHECK (expr));
 }
 
 
@@ -1326,7 +1308,7 @@ void vala_code_visitor_visit_type_check (ValaCodeVisitor* self, ValaTypeCheck* e
  */
 static void vala_code_visitor_real_visit_conditional_expression (ValaCodeVisitor* self, ValaConditionalExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CONDITIONAL_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CONDITIONAL_EXPRESSION (expr));
 }
 
 
@@ -1342,7 +1324,7 @@ void vala_code_visitor_visit_conditional_expression (ValaCodeVisitor* self, Vala
  */
 static void vala_code_visitor_real_visit_lambda_expression (ValaCodeVisitor* self, ValaLambdaExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_LAMBDA_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_LAMBDA_EXPRESSION (expr));
 }
 
 
@@ -1358,7 +1340,7 @@ void vala_code_visitor_visit_lambda_expression (ValaCodeVisitor* self, ValaLambd
  */
 static void vala_code_visitor_real_visit_assignment (ValaCodeVisitor* self, ValaAssignment* a) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (a == NULL || VALA_IS_ASSIGNMENT (a));
+	g_return_if_fail (VALA_IS_ASSIGNMENT (a));
 }
 
 
@@ -1374,7 +1356,7 @@ void vala_code_visitor_visit_assignment (ValaCodeVisitor* self, ValaAssignment*
  */
 static void vala_code_visitor_real_visit_end_full_expression (ValaCodeVisitor* self, ValaExpression* expr) {
 	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_EXPRESSION (expr));
 }
 
 
@@ -1383,6 +1365,16 @@ void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExp
 }
 
 
+/**
+ * Abstract code node visitor for traversing source code tree.
+ */
+ValaCodeVisitor* vala_code_visitor_new (void) {
+	ValaCodeVisitor * self;
+	self = g_object_newv (VALA_TYPE_CODE_VISITOR, 0, NULL);
+	return self;
+}
+
+
 static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	vala_code_visitor_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_code_visitor_real_visit_source_file;
@@ -1413,8 +1405,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_block = vala_code_visitor_real_visit_block;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_empty_statement = vala_code_visitor_real_visit_empty_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_declaration_statement = vala_code_visitor_real_visit_declaration_statement;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_local_variable_declaration = vala_code_visitor_real_visit_local_variable_declaration;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_variable_declarator = vala_code_visitor_real_visit_variable_declarator;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_local_variable = vala_code_visitor_real_visit_local_variable;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_initializer_list = vala_code_visitor_real_visit_initializer_list;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_expression_statement = vala_code_visitor_real_visit_expression_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_if_statement = vala_code_visitor_real_visit_if_statement;
