@@ -46,7 +46,7 @@ static void vala_delete_statement_dispose (GObject * obj);
 
 ValaDeleteStatement* vala_delete_statement_new (ValaExpression* expression, ValaSourceReference* source_reference) {
 	ValaDeleteStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_DELETE_STATEMENT, 0, NULL);
 	vala_delete_statement_set_expression (self, expression);
@@ -58,7 +58,7 @@ ValaDeleteStatement* vala_delete_statement_new (ValaExpression* expression, Vala
 static void vala_delete_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDeleteStatement * self;
 	self = VALA_DELETE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_delete_statement (visitor, self);
 }
 
@@ -66,7 +66,7 @@ static void vala_delete_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_delete_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDeleteStatement * self;
 	self = VALA_DELETE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_expression), visitor);
 }
 
