@@ -21,7 +21,7 @@
  */
 
 #include <vala/valaforeachstatement.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
@@ -32,9 +32,9 @@
 
 struct _ValaForeachStatementPrivate {
 	char* _variable_name;
-	ValaVariableDeclarator* _variable_declarator;
-	ValaVariableDeclarator* _collection_variable_declarator;
-	ValaVariableDeclarator* _iterator_variable_declarator;
+	ValaLocalVariable* _element_variable;
+	ValaLocalVariable* _collection_variable;
+	ValaLocalVariable* _iterator_variable;
 	ValaExpression* _collection;
 	ValaBlock* _body;
 	ValaDataType* _data_type;
@@ -46,9 +46,9 @@ enum  {
 	VALA_FOREACH_STATEMENT_VARIABLE_NAME,
 	VALA_FOREACH_STATEMENT_COLLECTION,
 	VALA_FOREACH_STATEMENT_BODY,
-	VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR,
-	VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR,
-	VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR
+	VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE,
+	VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE,
+	VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE
 };
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_foreach_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -72,10 +72,11 @@ ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference,
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForeachStatement * self;
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
-	g_return_val_if_fail (collection == NULL || VALA_IS_EXPRESSION (collection), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (variable_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (collection), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "variable-name";
@@ -87,9 +88,9 @@ ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference,
 	g_value_set_object (&__params_it->value, collection);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_FOREACH_STATEMENT, __params_it - __params, __params);
-	vala_foreach_statement_set_type_reference (self, type_reference);
 	vala_foreach_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_foreach_statement_set_type_reference (self, type_reference);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -102,7 +103,7 @@ ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference,
 static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_foreach_statement (visitor, self);
 }
 
@@ -110,7 +111,7 @@ static void vala_foreach_statement_real_accept (ValaCodeNode* base, ValaCodeVisi
 static void vala_foreach_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_type_reference (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_collection (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_foreach_statement_get_collection (self));
@@ -121,8 +122,8 @@ static void vala_foreach_statement_real_accept_children (ValaCodeNode* base, Val
 static void vala_foreach_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_foreach_statement_get_collection (self) == old_node) {
 		vala_foreach_statement_set_collection (self, new_node);
 	}
@@ -132,8 +133,8 @@ static void vala_foreach_statement_real_replace_expression (ValaCodeNode* base,
 static void vala_foreach_statement_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_foreach_statement_get_type_reference (self) == old_type) {
 		vala_foreach_statement_set_type_reference (self, new_type);
 	}
@@ -207,51 +208,51 @@ void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaBlock* val
 }
 
 
-ValaVariableDeclarator* vala_foreach_statement_get_variable_declarator (ValaForeachStatement* self) {
+ValaLocalVariable* vala_foreach_statement_get_element_variable (ValaForeachStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
-	return self->priv->_variable_declarator;
+	return self->priv->_element_variable;
 }
 
 
-void vala_foreach_statement_set_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value) {
-	ValaVariableDeclarator* _tmp2;
-	ValaVariableDeclarator* _tmp1;
+void vala_foreach_statement_set_element_variable (ValaForeachStatement* self, ValaLocalVariable* value) {
+	ValaLocalVariable* _tmp2;
+	ValaLocalVariable* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL))), _tmp2);
+	self->priv->_element_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (g_object_unref (self->priv->_element_variable), NULL))), _tmp2);
 }
 
 
-ValaVariableDeclarator* vala_foreach_statement_get_collection_variable_declarator (ValaForeachStatement* self) {
+ValaLocalVariable* vala_foreach_statement_get_collection_variable (ValaForeachStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
-	return self->priv->_collection_variable_declarator;
+	return self->priv->_collection_variable;
 }
 
 
-void vala_foreach_statement_set_collection_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value) {
-	ValaVariableDeclarator* _tmp2;
-	ValaVariableDeclarator* _tmp1;
+void vala_foreach_statement_set_collection_variable (ValaForeachStatement* self, ValaLocalVariable* value) {
+	ValaLocalVariable* _tmp2;
+	ValaLocalVariable* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_collection_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_collection_variable_declarator == NULL ? NULL : (self->priv->_collection_variable_declarator = (g_object_unref (self->priv->_collection_variable_declarator), NULL))), _tmp2);
+	self->priv->_collection_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (g_object_unref (self->priv->_collection_variable), NULL))), _tmp2);
 }
 
 
-ValaVariableDeclarator* vala_foreach_statement_get_iterator_variable_declarator (ValaForeachStatement* self) {
+ValaLocalVariable* vala_foreach_statement_get_iterator_variable (ValaForeachStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
-	return self->priv->_iterator_variable_declarator;
+	return self->priv->_iterator_variable;
 }
 
 
-void vala_foreach_statement_set_iterator_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value) {
-	ValaVariableDeclarator* _tmp2;
-	ValaVariableDeclarator* _tmp1;
+void vala_foreach_statement_set_iterator_variable (ValaForeachStatement* self, ValaLocalVariable* value) {
+	ValaLocalVariable* _tmp2;
+	ValaLocalVariable* _tmp1;
 	g_return_if_fail (VALA_IS_FOREACH_STATEMENT (self));
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	self->priv->_iterator_variable_declarator = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iterator_variable_declarator == NULL ? NULL : (self->priv->_iterator_variable_declarator = (g_object_unref (self->priv->_iterator_variable_declarator), NULL))), _tmp2);
+	self->priv->_iterator_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (g_object_unref (self->priv->_iterator_variable), NULL))), _tmp2);
 }
 
 
@@ -271,14 +272,14 @@ static void vala_foreach_statement_get_property (GObject * object, guint propert
 		case VALA_FOREACH_STATEMENT_BODY:
 		g_value_set_object (value, vala_foreach_statement_get_body (self));
 		break;
-		case VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR:
-		g_value_set_object (value, vala_foreach_statement_get_variable_declarator (self));
+		case VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE:
+		g_value_set_object (value, vala_foreach_statement_get_element_variable (self));
 		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR:
-		g_value_set_object (value, vala_foreach_statement_get_collection_variable_declarator (self));
+		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE:
+		g_value_set_object (value, vala_foreach_statement_get_collection_variable (self));
 		break;
-		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR:
-		g_value_set_object (value, vala_foreach_statement_get_iterator_variable_declarator (self));
+		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE:
+		g_value_set_object (value, vala_foreach_statement_get_iterator_variable (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -303,14 +304,14 @@ static void vala_foreach_statement_set_property (GObject * object, guint propert
 		case VALA_FOREACH_STATEMENT_BODY:
 		vala_foreach_statement_set_body (self, g_value_get_object (value));
 		break;
-		case VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR:
-		vala_foreach_statement_set_variable_declarator (self, g_value_get_object (value));
+		case VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE:
+		vala_foreach_statement_set_element_variable (self, g_value_get_object (value));
 		break;
-		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR:
-		vala_foreach_statement_set_collection_variable_declarator (self, g_value_get_object (value));
+		case VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE:
+		vala_foreach_statement_set_collection_variable (self, g_value_get_object (value));
 		break;
-		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR:
-		vala_foreach_statement_set_iterator_variable_declarator (self, g_value_get_object (value));
+		case VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE:
+		vala_foreach_statement_set_iterator_variable (self, g_value_get_object (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -333,9 +334,9 @@ static void vala_foreach_statement_class_init (ValaForeachStatementClass * klass
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_VARIABLE_NAME, g_param_spec_string ("variable-name", "variable-name", "variable-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION, g_param_spec_object ("collection", "collection", "collection", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_VARIABLE_DECLARATOR, g_param_spec_object ("variable-declarator", "variable-declarator", "variable-declarator", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE_DECLARATOR, g_param_spec_object ("collection-variable-declarator", "collection-variable-declarator", "collection-variable-declarator", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE_DECLARATOR, g_param_spec_object ("iterator-variable-declarator", "iterator-variable-declarator", "iterator-variable-declarator", VALA_TYPE_VARIABLE_DECLARATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ELEMENT_VARIABLE, g_param_spec_object ("element-variable", "element-variable", "element-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_COLLECTION_VARIABLE, g_param_spec_object ("collection-variable", "collection-variable", "collection-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOREACH_STATEMENT_ITERATOR_VARIABLE, g_param_spec_object ("iterator-variable", "iterator-variable", "iterator-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -348,9 +349,9 @@ static void vala_foreach_statement_dispose (GObject * obj) {
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (obj);
 	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
-	(self->priv->_variable_declarator == NULL ? NULL : (self->priv->_variable_declarator = (g_object_unref (self->priv->_variable_declarator), NULL)));
-	(self->priv->_collection_variable_declarator == NULL ? NULL : (self->priv->_collection_variable_declarator = (g_object_unref (self->priv->_collection_variable_declarator), NULL)));
-	(self->priv->_iterator_variable_declarator == NULL ? NULL : (self->priv->_iterator_variable_declarator = (g_object_unref (self->priv->_iterator_variable_declarator), NULL)));
+	(self->priv->_element_variable == NULL ? NULL : (self->priv->_element_variable = (g_object_unref (self->priv->_element_variable), NULL)));
+	(self->priv->_collection_variable == NULL ? NULL : (self->priv->_collection_variable = (g_object_unref (self->priv->_collection_variable), NULL)));
+	(self->priv->_iterator_variable == NULL ? NULL : (self->priv->_iterator_variable = (g_object_unref (self->priv->_iterator_variable), NULL)));
 	(self->priv->_collection == NULL ? NULL : (self->priv->_collection = (g_object_unref (self->priv->_collection), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
