@@ -1,11 +1,11 @@
 /* valaintegerliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAINTEGERLITERAL_H__
-#define __VALAINTEGERLITERAL_H__
+#ifndef __VALA_VALAINTEGERLITERAL_H__
+#define __VALA_VALAINTEGERLITERAL_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -46,18 +46,19 @@ typedef struct _ValaIntegerLiteralPrivate ValaIntegerLiteralPrivate;
  * Represents an integer literal in the source code.
  */
 struct _ValaIntegerLiteral {
-	ValaLiteral parent;
+	ValaLiteral parent_instance;
 	ValaIntegerLiteralPrivate * priv;
 };
 struct _ValaIntegerLiteralClass {
-	ValaLiteralClass parent;
+	ValaLiteralClass parent_class;
 };
 
 ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source);
 char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self);
 char* vala_integer_literal_get_value (ValaIntegerLiteral* self);
 void vala_integer_literal_set_value (ValaIntegerLiteral* self, const char* value);
-GType vala_integer_literal_get_type ();
+GType vala_integer_literal_get_type (void);
+
 
 G_END_DECLS
 
