@@ -56,8 +56,9 @@ ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* a
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaNamedArgument * self;
-	g_return_val_if_fail (arg == NULL || VALA_IS_EXPRESSION (arg), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (arg), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -82,7 +83,7 @@ ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* a
 static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamedArgument * self;
 	self = VALA_NAMED_ARGUMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_argument), visitor);
 	vala_code_visitor_visit_named_argument (visitor, self);
 }
