@@ -63,6 +63,8 @@ ValaMethod* vala_object_creation_expression_get_constructor (ValaObjectCreationE
 void vala_object_creation_expression_set_constructor (ValaObjectCreationExpression* self, ValaMethod* value);
 ValaMemberAccess* vala_object_creation_expression_get_member_name (ValaObjectCreationExpression* self);
 void vala_object_creation_expression_set_member_name (ValaObjectCreationExpression* self, ValaMemberAccess* value);
+gboolean vala_object_creation_expression_get_struct_creation (ValaObjectCreationExpression* self);
+void vala_object_creation_expression_set_struct_creation (ValaObjectCreationExpression* self, gboolean value);
 GType vala_object_creation_expression_get_type (void);
 
 
