@@ -51,7 +51,8 @@ static void vala_real_literal_dispose (GObject * obj);
  */
 ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* source) {
 	ValaRealLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (r != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_REAL_LITERAL, 0, NULL);
 	vala_real_literal_set_value (self, r);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -62,7 +63,7 @@ ValaRealLiteral* vala_real_literal_new (const char* r, ValaSourceReference* sour
 static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaRealLiteral * self;
 	self = VALA_REAL_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_real_literal (visitor, self);
 }
 
@@ -74,7 +75,7 @@ static void vala_real_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  */
 char* vala_real_literal_get_type_name (ValaRealLiteral* self) {
 	g_return_val_if_fail (VALA_IS_REAL_LITERAL (self), NULL);
-	if (g_str_has_suffix (self->priv->_value, "F")) {
+	if (g_str_has_suffix (self->priv->_value, "f") || g_str_has_suffix (self->priv->_value, "F")) {
 		return g_strdup ("float");
 	}
 	return g_strdup ("double");
